Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: chrome/browser/ui/ash/chrome_launcher_prefs.h

Issue 2860503002: mash: Replace int ShelfIDs with AppLaunchID strings. (Closed)
Patch Set: Restore AppLaunchId class via using ShelfID = AppLaunchId; cleanup. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/chrome_launcher_prefs.h
diff --git a/chrome/browser/ui/ash/chrome_launcher_prefs.h b/chrome/browser/ui/ash/chrome_launcher_prefs.h
index 00022aa80c474048e0b074be53c19c14b7dc3da0..f4a14434c60a577117c197a83d23daca2f177f68 100644
--- a/chrome/browser/ui/ash/chrome_launcher_prefs.h
+++ b/chrome/browser/ui/ash/chrome_launcher_prefs.h
@@ -26,9 +26,6 @@ class PrefRegistrySyncable;
}
namespace ash {
James Cook 2017/05/04 16:38:49 Hey, while you're here can you take this file out
msw 2017/05/04 19:05:57 I 100% agree, but I'll do it in a followup, this C
James Cook 2017/05/04 19:45:08 SGTM
-
-class AppLaunchId;
-
namespace launcher {
// Path within the dictionary entries in the prefs::kPinnedLauncherApps list
@@ -67,23 +64,22 @@ void SetShelfAlignmentPref(PrefService* prefs,
ShelfAlignment alignment);
// Get the list of pinned apps from preferences.
-std::vector<AppLaunchId> GetPinnedAppsFromPrefs(
- const PrefService* prefs,
- LauncherControllerHelper* helper);
-
-// Removes information about pin position from sync model for the app. Note,
-// |app_launch_id| with non-empty launch_id is not supported.
-void RemovePinPosition(Profile* profile, const AppLaunchId& app_launch_id);
-
-// Updates information about pin position in sync model for the app
-// |app_launch_id|. |app_launch_id_before| optionally specifies an app that
-// exists right before the target app. |app_launch_ids_after| optionally
-// specifies sorted by position apps that exist right after the target app.
-// Note, |app_launch_id| with non-empty launch_id is not supported.
+std::vector<ShelfID> GetPinnedAppsFromPrefs(const PrefService* prefs,
+ LauncherControllerHelper* helper);
+
+// Removes information about pin position from sync model for the app.
+// Note, |shelf_id| with non-empty launch_id is not supported.
+void RemovePinPosition(Profile* profile, const ShelfID& shelf_id);
+
+// Updates information about pin position in sync model for the app |shelf_id|.
+// |shelf_id_before| optionally specifies an app that exists right before the
+// target app. |shelf_ids_after| optionally specifies sorted by position apps
+// that exist right after the target app.
+// Note, |shelf_id| with non-empty launch_id is not supported.
void SetPinPosition(Profile* profile,
- const AppLaunchId& app_launch_id,
- const AppLaunchId& app_launch_id_before,
- const std::vector<AppLaunchId>& app_launch_ids_after);
+ const ShelfID& shelf_id,
+ const ShelfID& shelf_id_before,
+ const std::vector<ShelfID>& shelf_ids_after);
// Used to propagate remote preferences to local during the first run.
class ChromeLauncherPrefsObserver

Powered by Google App Engine
This is Rietveld 408576698